@@ -4,6 +4,7 @@ import (
 	"context"
 	"path/filepath"
 	"testing"
+	"time"
 
 	"github.com/onsi/ginkgo"
 	"github.com/onsi/gomega"
@@ -19,6 +20,7 @@ import (
 
 	operatorclient "github.com/open-cluster-management/api/client/operator/clientset/versioned"
 	operatorapiv1 "github.com/open-cluster-management/api/operator/v1"
+	"github.com/open-cluster-management/registration-operator/pkg/operators/klusterlet/controllers/bootstrapcontroller"
 )
 
 func TestIntegration(t *testing.T) {
@@ -47,13 +49,17 @@ var _ = ginkgo.BeforeSuite(func(done ginkgo.Done) {
 
 	ginkgo.By("bootstrapping test environment")
 
+	// crank up the sync speed
+	bootstrapcontroller.BootstrapControllerSyncInterval = 2 * time.Second
+
 	var err error
 
 	// install registration-operator CRDs and start a local kube-apiserver
 	testEnv = &envtest.Environment{
 		ErrorIfCRDPathMissing: true,
 		CRDDirectoryPaths: []string{
-			filepath.Join(".", "vendor", "github.com", "open-cluster-management", "api", "operator", "v1"),
+			filepath.Join(".", "deploy", "cluster-manager", "olm-catalog", "cluster-manager", "manifests"),
+			filepath.Join(".", "deploy", "klusterlet", "olm-catalog", "klusterlet", "manifests"),
 		},
 	}
 	cfg, err := testEnv.Start()
